summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>2011-05-31 00:19:56 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>2011-05-31 00:19:56 +0000
commit036e9c517dc25bb70502a866c9e6a0f68b1328a8 (patch)
treef5671c4d1a03e3822dd8994f1cede58a52f76064 /sys
parent78872ddf76a2bcd006c989787de8f31d609c66fb (diff)
Family 14h also supports the km(4) temperature sensor
from brad
Diffstat (limited to 'sys')
-rw-r--r--sys/dev/pci/km.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/sys/dev/pci/km.c b/sys/dev/pci/km.c
index 48589ff4cf6..ececd3cb955 100644
--- a/sys/dev/pci/km.c
+++ b/sys/dev/pci/km.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: km.c,v 1.4 2009/01/26 15:07:49 kettenis Exp $ */
+/* $OpenBSD: km.c,v 1.5 2011/05/31 00:19:55 deraadt Exp $ */
/*
* Copyright (c) 2008 Constantine A. Murenin <cnst+openbsd@bugmail.mojo.ru>
@@ -29,7 +29,7 @@
/*
* AMD Family 10h/11h Processors, Function 3 -- Miscellaneous Control
*/
/* Function 3 Registers */
@@ -69,7 +69,8 @@ struct cfdriver km_cd = {
static const struct pci_matchid km_devices[] = {
{ PCI_VENDOR_AMD, PCI_PRODUCT_AMD_AMD64_10_MISC },
- { PCI_VENDOR_AMD, PCI_PRODUCT_AMD_AMD64_11_MISC }
+ { PCI_VENDOR_AMD, PCI_PRODUCT_AMD_AMD64_11_MISC },
+ { PCI_VENDOR_AMD, PCI_PRODUCT_AMD_AMD64_14_MISC }
};
@@ -29,7 +29,7 @@
/*
- * AMD Family 10h/11h Processors, Function 3 -- Miscellaneous Control
+ * AMD Family 10h/11h/14h Processors, Function 3 -- Miscellaneous Control
*/
/* Function 3 Registers */